[Scummvm-cvs-logs] scummvm master -> b105104534d31fc80fb73ba34bf1913d1cd4cb87

clone2727 clone2727 at gmail.com
Thu Sep 20 18:02:25 CEST 2012


This automated email contains information about 2 new commits which have been
pushed to the 'scummvm' repo located at https://github.com/scummvm/scummvm .

Summary:
2a9d98003e SCUMM: Restrict the Mac m68k v5 driver to MI2/Indy4
b105104534 SCUMM: Update comments


Commit: 2a9d98003e07890dc74694b62bd694d1fc8a19f3
    https://github.com/scummvm/scummvm/commit/2a9d98003e07890dc74694b62bd694d1fc8a19f3
Author: Matthew Hoops (clone2727 at gmail.com)
Date: 2012-09-20T08:58:04-07:00

Commit Message:
SCUMM: Restrict the Mac m68k v5 driver to MI2/Indy4

Shouldn't be used with MI1

Changed paths:
    engines/scumm/detection.cpp
    engines/scumm/imuse/imuse_part.cpp
    engines/scumm/scumm.cpp
    engines/scumm/scumm.h
    engines/scumm/sound.cpp



diff --git a/engines/scumm/detection.cpp b/engines/scumm/detection.cpp
index 156d1fb..e5c3023 100644
--- a/engines/scumm/detection.cpp
+++ b/engines/scumm/detection.cpp
@@ -242,8 +242,8 @@ static Common::String generateFilenameForDetection(const char *pattern, Filename
 	return result;
 }
 
-bool ScummEngine::isMacM68kV5() const {
-	return _game.platform == Common::kPlatformMacintosh && _game.version == 5 && !(_game.features & GF_MAC_CONTAINER);
+bool ScummEngine::isMacM68kIMuse() const {
+	return _game.platform == Common::kPlatformMacintosh && (_game.id == GID_MONKEY2 || _game.id == GID_INDY4) && !(_game.features & GF_MAC_CONTAINER);
 }
 
 struct DetectorDesc {
diff --git a/engines/scumm/imuse/imuse_part.cpp b/engines/scumm/imuse/imuse_part.cpp
index bb319df..9c720b7 100644
--- a/engines/scumm/imuse/imuse_part.cpp
+++ b/engines/scumm/imuse/imuse_part.cpp
@@ -372,7 +372,7 @@ void Part::set_instrument(uint b) {
 	// We emulate this by introducing a special instrument, which sets
 	// the instrument via sysEx_customInstrument. This seems to be
 	// exclusively used for special sound effects like the "spit" sound.
-	if (g_scumm->isMacM68kV5()) {
+	if (g_scumm->isMacM68kIMuse()) {
 		_instrument.macSfx(b);
 	} else {
 		_instrument.program((byte)b, _player->isMT32());
diff --git a/engines/scumm/scumm.cpp b/engines/scumm/scumm.cpp
index 2150bbc..c9c9e99 100644
--- a/engines/scumm/scumm.cpp
+++ b/engines/scumm/scumm.cpp
@@ -1839,7 +1839,7 @@ void ScummEngine::setupMusic(int midi) {
 		bool multi_midi = ConfMan.getBool("multi_midi") && _sound->_musicType != MDT_NONE && _sound->_musicType != MDT_PCSPK && (midi & MDT_ADLIB);
 		bool useOnlyNative = false;
 
-		if (isMacM68kV5()) {
+		if (isMacM68kIMuse()) {
 			// We setup this driver as native MIDI driver to avoid playback
 			// of the Mac music via a selected MIDI device.
 			nativeMidiDriver = new MacM68kDriver(_mixer);
diff --git a/engines/scumm/sound.cpp b/engines/scumm/sound.cpp
index 3215242..60a7fbe 100644
--- a/engines/scumm/sound.cpp
+++ b/engines/scumm/sound.cpp
@@ -250,7 +250,7 @@ void Sound::playSound(int soundID) {
 	// Support for sampled sound effects in Monkey Island 1 and 2
 	else if (_vm->_game.platform != Common::kPlatformFMTowns
 	         // The Macintosh version of MI2 just ignores SBL effects.
-	         && !_vm->isMacM68kV5()
+	         && !_vm->isMacM68kIMuse()
 	         && READ_BE_UINT32(ptr) == MKTAG('S','B','L',' ')) {
 		debugC(DEBUG_SOUND, "Using SBL sound effect");
 


Commit: b105104534d31fc80fb73ba34bf1913d1cd4cb87
    https://github.com/scummvm/scummvm/commit/b105104534d31fc80fb73ba34bf1913d1cd4cb87
Author: Matthew Hoops (clone2727 at gmail.com)
Date: 2012-09-20T09:00:13-07:00

Commit Message:
SCUMM: Update comments

Changed paths:
    engines/scumm/imuse/imuse_part.cpp
    engines/scumm/sound.cpp



diff --git a/engines/scumm/imuse/imuse_part.cpp b/engines/scumm/imuse/imuse_part.cpp
index 9c720b7..89c16a8 100644
--- a/engines/scumm/imuse/imuse_part.cpp
+++ b/engines/scumm/imuse/imuse_part.cpp
@@ -367,7 +367,7 @@ void Part::set_instrument(uint b) {
 	if (_bank)
 		error("Non-zero instrument bank selection. Please report this");
 	// HACK: Horrible hack to allow tracing of program change source.
-	// The Mac version of Monkey Island 2 uses a different program "bank"
+	// The Mac m68k versions of MI2 and Indy4 use a different program "bank"
 	// when it gets program change events through the iMuse SysEx handler.
 	// We emulate this by introducing a special instrument, which sets
 	// the instrument via sysEx_customInstrument. This seems to be
diff --git a/engines/scumm/sound.cpp b/engines/scumm/sound.cpp
index 60a7fbe..43c86db 100644
--- a/engines/scumm/sound.cpp
+++ b/engines/scumm/sound.cpp
@@ -249,7 +249,7 @@ void Sound::playSound(int soundID) {
 	}
 	// Support for sampled sound effects in Monkey Island 1 and 2
 	else if (_vm->_game.platform != Common::kPlatformFMTowns
-	         // The Macintosh version of MI2 just ignores SBL effects.
+	         // The Macintosh m68k versions of MI2/Indy4 just ignore SBL effects.
 	         && !_vm->isMacM68kIMuse()
 	         && READ_BE_UINT32(ptr) == MKTAG('S','B','L',' ')) {
 		debugC(DEBUG_SOUND, "Using SBL sound effect");






More information about the Scummvm-git-logs mailing list
diff --git a/engines/scumm/scumm.h b/engines/scumm/scumm.h
index 555b708..7003894 100644
--- a/engines/scumm/scumm.h
+++ b/engines/scumm/scumm.h
@@ -719,8 +719,8 @@ public:
 
 	bool openFile(BaseScummFile &file, const Common::String &filename, bool resourceFile = false);
 
-	/** Is this game a Mac m68k v5 game? */
-	bool isMacM68kV5() const;
+	/** Is this game a Mac m68k v5 game with iMuse? */
+	bool isMacM68kIMuse() const;
 
 protected:
 	int _resourceHeaderSize;